#
# spec file for package librtas
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 2
Name:           librtas
Version:        2.0.5
Release:        150600.1.15
Summary:        Libraries to provide access to RTAS calls and RTAS events
License:        LGPL-2.1-or-later
Group:          System/Libraries
URL:            https://github.com/ibm-power-utilities/librtas
Source0:        https://github.com/ibm-power-utilities/librtas/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        baselibs.conf
Patch0:         librtas.fix_doc_path.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
ExclusiveArch:  ppc ppc64 ppc64le

%description
The librtas shared library provides userspace with an interface through
which certain RTAS calls can be made.  The library uses either of the
RTAS User Module or the RTAS system call to direct the kernel in making
these calls.

The librtasevent shared library provides users with a set of
definitions and common routines useful in parsing and dumping the
contents of RTAS events.

%package        devel
Summary:        Devel librtas files
Group:          Development/Libraries/C and C++
BuildRequires:  pkgconfig
Requires:       %{name}%{sover} = %{version}

%description devel
This package provides devel files of librtas

%package        devel-static
Summary:        Static librtas files
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}

%description devel-static
This package provides devel files of librtas

%package     -n %{name}%{sover}
Summary:        Libraries to provide access to RTAS calls and RTAS events
Group:          System/Libraries

%description -n %{name}%{sover}
The librtas shared library provides userspace with an interface through
which certain RTAS calls can be made.  The library uses either of the
RTAS User Module or the RTAS system call to direct the kernel in making
these calls.

The librtasevent shared library provides users with a set of
definitions and common routines useful in parsing and dumping the
contents of RTAS events.

%prep
%autosetup -p1

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
./autogen.sh
%configure
%make_build CFLAGS="%{optflags} -fPIC -g -I $PWD/librtasevent_src" LIB_DIR="%{_libdir}"

%install
rm -rf doc/*/latex
make install DESTDIR=%{buildroot} LIB_DIR="%{_libdir}"
# documents are in -doc subpackage
rm -rf %{buildroot}/%{_docdir}
/sbin/ldconfig -n %{buildroot}%{_libdir}
chmod -x %{buildroot}%{_libdir}/*.a
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%license COPYING.LESSER
%doc Changelog README
%{_libdir}/lib*.so.*

%files devel
%license COPYING.LESSER
%{_libdir}/librtasevent.so
%{_libdir}/librtas.so
%{_includedir}/librtas.h
%{_includedir}/librtasevent.h
%{_includedir}/librtasevent_v4.h
%{_includedir}/librtasevent_v6.h

%files devel-static
%license COPYING.LESSER
%{_libdir}/librtas.a
%{_libdir}/librtasevent.a

%changelog
* Mon Nov 20 2023 msuchanek@suse.com
- Update to version 2.0.5 (jsc#PED-554)
  * librtas: fix buffer length determination in rtas_set_sysparm()
  * librtasevent: 'format' function attribute for printf-style functions
  * convert PAGE_SIZE to WORK_AREA_SIZE
* Thu May  4 2023 dimstar@opensuse.org
- Add _multibuild to define 2nd spec file as additional flavor.
  Eliminates the need for source package links in OBS.
* Wed Jan 25 2023 msuchanek@suse.com
- Update to version 2.0.4 (jsc#PED-554)
  - fix possible call to munmap with garbage value
- Refresh librtas.fix_doc_path.patch
* Fri Jan 20 2023 msuchanek@suse.com
- Update to version 2.0.3
  - Fix memory page address print issue
- Remove upstreamed patch
  - librtasevent-Fix-memory-page-address-print-issue.patch
- Refresh spec file
* Wed Jan 12 2022 msuchanek@suse.com
- librtasevent: Fix memory page address print issue (bsc#1193846 ltc#193949).
  + librtasevent-Fix-memory-page-address-print-issue.patch
* Sun Sep 15 2019 normand@linux.vnet.ibm.com
- Add -ffat-lto-objects to avoid ppc64le build error
* Mon Jul  2 2018 jloeser@suse.com
- version update to 2.0.2 (fate#324947)
  * interface for ibm,physical-attestation rtas call
* Tue Aug 29 2017 jloeser@suse.com
- add missing references for SLE merge:
  * bsc#902243
  * fate#321599
  * fate#318014
* Mon Apr  3 2017 jloeser@suse.com
- adjust url/source
* Mon Oct 10 2016 jloeser@suse.com
- version update to 2.0.1 (fate#323766)
  * Fix endianess issue in errinjct rtas call
- added patches:
  * librtas.fix_doc_path.patch
- removed patches:
  * librtas.bug-985643_open_RTAS_error_facility.patch
  * librtas-failedmagic.patch
* Mon Jul 25 2016 jloeser@suse.com
- fix for opening RTAS error injection facility (bsc#985643)
- added patches:
  * librtas.bug-985643_open_RTAS_error_facility.patch
* Mon Jun 27 2016 normand@linux.vnet.ibm.com
- version update to 2.0.0 (bsc#981294)
  * SO version change from 1 -> 2
  * generate static libraries
  * minor fixes (see Changelog)
* Mon Jun 13 2016 mlin@suse.com
- Split off documents to -doc sub-package
  * We can't really add doxygen to Ring0 which required by -doc
* Wed Mar  2 2016 jloeser@suse.com
- version update to 1.4.0 (FATE#319934)
  - see Changelog under librtas-1.4.0/Changelog
* Wed Oct 29 2014 jloeser@suse.com
- version update to 1.3.13
  see changelog for changes
* Fri Sep  5 2014 jengelh@inai.de
- RPM group classification; add project web locations
* Fri Sep  5 2014 jloeser@suse.com
- version update to 1.3.12 (BNC#894854)
  - get_sensor, set_sensor: Handle big endian data in little endian
  - fix for sc_platform_dump endian handling
* Thu Jul  3 2014 pth@suse.de
- Update to 1.3.11 (bnc#884710:
  * README: documentation on handling endianness
  * librtas: Little endian support in syscalls
  See Changelog in the package documentation for the full changes
  documentation.
- Refresh librtas-failedmagic.patch.
- Packege Changelog
- No need to remove and create buildroot, that's done by osc.
* Tue Mar 25 2014 jloeser@suse.com
- version update to 1.3.10 (BNC#870006)
  see changelog for change
* Tue Mar  4 2014 jloeser@suse.com
- change license to CPL-1.0 (see COPYRIGHT)
* Tue Mar  4 2014 jloeser@suse.com
- version update to 1.3.9 (BNC#866674)
  see changelog for changes
* Mon Dec  9 2013 dvaleev@suse.com
- enable ppc64le
* Sun Feb 24 2013 dvaleev@suse.com
- Update to 1.3.8
  * Identify Platform Resource Reassignment Notifications (PRRN)
* Fri Dec 28 2012 dvaleev@suse.com
- update to 1.3.7
  librtas allocates buffer space (required for RTAS call) in the
    RTAS private     memory area through sc_get_rmo_buffer() which
    internally allocates memory     and protects it by acquiring
    lock on the allocated memory area.
    Locking function :
    At present acquire_file_lock() tries to lock the particular
    memory area. If the memory area is already locked then it
    returns error without retrying.
    So when two process executes rtas call simultaneously one fails
    with "Unknown librtas I/O" error.
    This patch introduces "Wait for lock to be available" instead
    of returning with IO error.
- fixed minor memory leak in librtas.so
* Tue Jan 31 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Parallel building using %%_smp_mflags
* Mon Nov 14 2011 dvaleev@suse.com
- update -> 1.3.6
  - changes and small fixes in regards to lib64 support mostly
- split up devel, doc packages
- split librtas1 package according shared library policy
- patch refresh
- fix baselibs.conf
- fix %%files permission
* Fri Nov 20 2009 uli@suse.de
- update -> 1.3.4:
  - new inventory model (fate#304149)
  - support rtas event updates (fate#307049)
* Wed Nov  5 2008 ro@suse.de
- added baselibs.conf (bnc#434975)
* Tue Oct 28 2008 olh@suse.de
- fix header compilation (bnc#439321, bnc#439327)
* Fri Feb 15 2008 sassmann@suse.de
- update to librtas-1.3.3 (bnc#361305)
- removed errno patch (included upstream)
* Mon Jan 21 2008 olh@suse.de
- use correct open mode for O_CREAT
  fix out-of-bounds access in parse_post_scn()
  fix errno assingment in parse_fru_*_scn()
* Tue Nov 13 2007 sassmann@suse.de
- added patch
  librtas.libdir-fix-for-64bit.patch
  libraries need to be in lib64 instead of lib on ppc64,
  this patch alters the various Makefiles to achieve this.
* Wed Nov  7 2007 sassmann@suse.de
- fixed wrong release number
* Mon Nov  5 2007 sassmann@suse.de
- added arch ppc64 for build
- Patch librtas.signed-char.patch removed
- Patch librtas.syscall.patch removed
* Tue Oct 16 2007 sassmann@suse.de
- update to librtas-1.3.2 (feature #302692)
- patches disabled
  Patch0:         librtas.signed-char.patch
  Patch1:         librtas.syscall.patch
* Fri Oct 13 2006 olh@suse.de
- fix off by one in open_prop_file
* Fri Jan 27 2006 olh@suse.de
- package soname symlink
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Dec  9 2005 olh@suse.de
- use unsigned char for fprintf. The rtas_dump output will be
  corrupt, depending on the input data (#93851)
* Fri Oct 28 2005 olh@suse.de
- update to version 1.2.4 (130214 - LTC19273)
* Wed Oct 26 2005 olh@suse.de
- update to version 1.2.3 (130214 - LTC19273)
  fixes for date parsing and vendor event parsing
* Thu Oct 13 2005 olh@suse.de
- create 32bit package librtas 1.2
